==> dde-session-shell_5.4.13.orig.tar.xz: dde-session-shell-5.4.13/translations/dde-session-shell_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
<context>
    <name>ContentWidget</name>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="357"/>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Programi preprečujejo računalniku, da bi se zaustavil, prisilna zaustavitev pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="358"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="363"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="367"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="371"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="375"/>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Da bi program zaprli, klknite Prekini in nato zaprite program.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="362"/>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Programi preprečujejo računalniku, da bi se ponovno zagnal, prisilna zaustavitev pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="366"/>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Programi preprečujejo računalniku, da bi obmiroval, prisilna zaustavitev pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="370"/>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Programi preprečujejo računalniku, da bi zaspal, prisilna zaustavitev pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="374"/>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Programi preprečujejo računalniku, da bi se odjavil prisilna zaustavitev pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="391"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="435"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="460"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="614"/>
        <source>Shut down</source>
        <translation>Zaustavitev sistema</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="394"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="437"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="463"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="617"/>
        <source>Reboot</source>
        <translation>Ponovni zagon</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="397"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="620"/>
        <source>Suspend</source>
        <translation>Mirovanje</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="399"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="623"/>
        <source>Hibernate</source>
        <translation>Spanje</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="401"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="466"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="629"/>
        <source>Log out</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="461"/>
        <source>Are you sure you want to shut down?</source>
        <translation>Ste prepričani, da želite zaustaviti sistem?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="464"/>
        <source>Are you sure you want to reboot?</source>
        <translation>Ste prepričani, da žeelite ponovni zagon?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="467"/>
        <source>Are you sure you want to log out?</source>
        <translation>Ste preričani, da se želite odjaviti?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="626"/>
        <source>Lock</source>
        <translation>Zakleni</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="632"/>
        <source>Switch user</source>
        <translation>Zamenjaj uporabnika</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="637"/>
        <source>Switch system</source>
        <translation>Zamenjaj sistem</translation>
    </message>
</context>
<context>
    <name>GreeterWorkek</name>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="329"/>
        <source>Wrong Password</source>
        <translation>Napačno geslo</translation>
    </message>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="333"/>
        <source>The account or password is not correct. Please enter again.</source>
        <translation>Račun ali geslo sta napačna. Poskusite ponovno.</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <location filename="../src/dde-shutdown/view/inhibitwarnview.cpp" line="90"/>
        <location filename="../src/widgets/inhibitwarnview.cpp" line="90"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="430"/>
        <source>Lock Screen</source>
        <translation>Zakleni zaslon</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="434"/>
        <source>Failed to lock screen</source>
        <translation>Ni bilo mogoče zakleniti zaslona</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="275"/>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Preverjanje prstnega odtisa ni bilo uspešno, vnesite geslo</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="293"/>
        <source>Failed to match fingerprint</source>
        <translation>Neustrezen prstni odtis</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="324"/>
        <source>Wrong Password</source>
        <translation>Napačno geslo</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="45"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="45"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="130"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="130"/>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Navedeni uporabniki so še vedno prijavljeni in njihovi podatki bodo izgubljeni, če bo sistem zaustavljen. Želite vseeno zaustaviti sistem?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="134"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="134"/>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Navedeni uporabniki so še vedno prijavljeni in njihovi podatki bodo izgubljeni, če bo sistem ponovno zagnan. Želite vseeno zaustaviti sistem?</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="30"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="190"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="234"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="259"/>
        <source>Shut down</source>
        <translation>Zaustavitev sistema</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="31"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="193"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="236"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="262"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="340"/>
        <source>Reboot</source>
        <translation>Ponovni zagon</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="32"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="196"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="346"/>
        <source>Suspend</source>
        <translation>Mirovanje</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="33"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="198"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="352"/>
        <source>Hibernate</source>
        <translation>Spanje</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="156"/>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Programi preprečujejo zaustavitev sistema, prisiljena zaustavitev pa ima lahko za posledico izgubo podatkov.</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="157"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="162"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="166"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="170"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="174"/>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Za zapiranje programa kliknite na Prekini, nato pa zaprite program.</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="161"/>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Programi preprečujejo ponovni zagon, prisilni ponovni zagon pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="165"/>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Programi preprečujejo računalniku, da bi obmiroval, prisilno obmirovanje pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="169"/>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Programi preprečujejo računalniku, da bi zaspal, prisilno spanje pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="173"/>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Programi preprečujejo odjavo, prisilna odjava pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="200"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="265"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="364"/>
        <source>Log out</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="260"/>
        <source>Are you sure you want to shut down?</source>
        <translation>Ste prepričani, da želite zaustaviti sistem?</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="263"/>
        <source>Are you sure you want to reboot?</source>
        <translation>Ste prepričani, da želite ponovni zagon?</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="266"/>
        <source>Are you sure you want to log out?</source>
        <translation>Ste prepričani, da se želite odjaviti?</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="358"/>
        <source>Lock</source>
        <translation>Zakleni</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="370"/>
        <source>Switch user</source>
        <translation>Zamenjaj uporabnika</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="378"/>
        <source>Switch system</source>
        <translation>Zamenjaj sistem</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <location filename="../src/dde-shutdown/view/systemmonitor.cpp" line="45"/>
        <location filename="../src/widgets/systemmonitor.cpp" line="45"/>
        <source>Start system monitor</source>
        <translation>Zaženi nadzornika sistema</translation>
    </message>
</context>
<context>
    <name>UserLoginWidget</name>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="193"/>
        <source>Password</source>
        <translation>Geslo</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="197"/>
        <source>Account</source>
        <translation>Račun</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="239"/>
        <source>Please enter the account</source>
        <translation>Vnesite račun</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="246"/>
        <source>Please enter the password</source>
        <translation>Vnesite geslo</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/session-widgets/userloginwidget.cpp" line="338"/>
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Pokusite znova %n minuto kasneje</numerusform><numerusform>Pokusite znova %n minuti kasneje</numerusform><numerusform>Pokusite znova %n minute kasneje</numerusform><numerusform>Pokusite znova %n minut kasneje</numerusform></translation>
    </message>
</context>
</TS>

==> dde-session-shell_5.5.34.orig.tar.xz: dde-session-shell-5.5.34/translations/dde-session-shell_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Preverite prstni odtis</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Uspešno preverjanje</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Preverjanje ni uspelo. Še %n poskus</numerusform><numerusform>Preverjanje ni uspelo. Še %n poskusa</numerusform><numerusform>Preverjanje ni uspelo. Še %n poskusi</numerusform><numerusform>Preverjanje ni uspelo. Še %n poskusov</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Neuspešna overitev. Ostal je le še en poskus</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Prstni odtis je zaklenjen, uporabite geslo</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Pokusite znova %n minuto kasneje</numerusform><numerusform>Pokusite znova %n minuti kasneje</numerusform><numerusform>Pokusite znova %n minute kasneje</numerusform><numerusform>Pokusite znova %n minut kasneje</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Uspešno preverjanje</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Preverjanje ni uspelo. Še %n poskus</numerusform><numerusform>Preverjanje ni uspelo. Še %n poskusa</numerusform><numerusform>Preverjanje ni uspelo. Še %n poskusi</numerusform><numerusform>Preverjanje ni uspelo. Še %n poskusov</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Neuspešna overitev. Ostal je le še en poskus</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Napačno geslo</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Geslo</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Pokusite znova %n minuto kasneje</numerusform><numerusform>Pokusite znova %n minuti kasneje</numerusform><numerusform>Pokusite znova %n minute kasneje</numerusform><numerusform>Pokusite znova %n minut kasneje</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Pokusite znova minuto kasneje</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Pokusite znova %n minuto kasneje</numerusform><numerusform>Pokusite znova %n minuti kasneje</numerusform><numerusform>Pokusite znova %n minute kasneje</numerusform><numerusform>Pokusite znova %n minut kasneje</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Uspešno preverjanje</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Preverjanje ni uspelo. Še %n poskus</numerusform><numerusform>Preverjanje ni uspelo. Še %n poskusa</numerusform><numerusform>Preverjanje ni uspelo. Še %n poskusi</numerusform><numerusform>Preverjanje ni uspelo. Še %n poskusov</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Neuspešna overitev. Ostal je le še en poskus</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Napačen PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>Zahtevan je UKey</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Vnesite PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Pokusite znova %n minuto kasneje</numerusform><numerusform>Pokusite znova %n minuti kasneje</numerusform><numerusform>Pokusite znova %n minute kasneje</numerusform><numerusform>Pokusite znova %n minut kasneje</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthenticationModule</name>
    <message>
        <source>Verification successful</source>
        <translation>Uspešno preverjanje</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Preverjanje ni uspelo. Še %n poskus</numerusform><numerusform>Preverjanje ni uspelo. Še %n poskusa</numerusform><numerusform>Preverjanje ni uspelo. Še %n poskusi</numerusform><numerusform>Preverjanje ni uspelo. Še %n poskusov</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Neuspešna overitev. Ostal je le še en poskus</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Napačno geslo</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Napačen PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>Zahtevan je UKey</translation>
    </message>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Preverite prstni odtis</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Geslo</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Vnesite PIN</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Prstni odtis je zaklenjen, uporabite geslo</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Pokusite znova minuto kasneje</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Pokusite znova %n minuto kasneje</numerusform><numerusform>Pokusite znova %n minuti kasneje</numerusform><numerusform>Pokusite znova %n minute kasneje</numerusform><numerusform>Pokusite znova %n minut kasneje</numerusform></translation>
    </message>
</context>
<context>
    <name>ContentWidget</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Programi preprečujejo računalniku, da bi se zaustavil, prisilna zaustavitev pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Da bi program zaprli, klknite Prekini in nato zaprite program.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Programi preprečujejo računalniku, da bi se ponovno zagnal, prisilna zaustavitev pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Programi preprečujejo računalniku, da bi obmiroval, prisilna zaustavitev pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Programi preprečujejo računalniku, da bi zaspal, prisilna zaustavitev pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Programi preprečujejo računalniku, da bi se odjavil prisilna zaustavitev pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Zaustavitev sistema</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Ponovni zagon</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Mirovanje</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Spanje</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Ste prepričani, da želite zaustaviti sistem?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Ste prepričani, da žeelite ponovni zagon?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Ste preričani, da se želite odjaviti?</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zakleni</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Zamenjaj uporabnika</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Zamenjaj sistem</translation>
    </message>
</context>
<context>
    <name>GreeterWorkek</name>
    <message>
        <source>Wrong account</source>
        <translation>Napačen račun</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Napačno geslo</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Zakleni zaslon</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Ni bilo mogoče zakleniti zaslona</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Preverjanje prstnega odtisa ni bilo uspešno, vnesite geslo</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Neustrezen prstni odtis</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Navedeni uporabniki so še vedno prijavljeni in njihovi podatki bodo izgubljeni, če bo sistem zaustavljen. Želite vseeno zaustaviti sistem?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Navedeni uporabniki so še vedno prijavljeni in njihovi podatki bodo izgubljeni, če bo sistem ponovno zagnan. Želite vseeno zaustaviti sistem?</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Zaustavitev sistema</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Ponovni zagon</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Mirovanje</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Spanje</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zakleni</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Zamenjaj uporabnika</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Zamenjaj sistem</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Zaženi nadzornika sistema</translation>
    </message>
</context>
<context>
    <name>UserLoginWidget</name>
    <message>
        <source>Account</source>
        <translation>Račun</translation>
    </message>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Preverite prstni odtis</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>Vaše geslo bo poteklo v %n dnevu. Pravočasno ga zamenjajte</numerusform><numerusform>Vaše geslo bo poteklo v %n dneh. Pravočasno ga zamenjajte</numerusform><numerusform>Vaše geslo bo poteklo v %n dneh. Pravočasno ga zamenjajte</numerusform><numerusform>Vaše geslo bo poteklo v %n dneh. Pravočasno ga zamenjajte</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Geslo je poteklo. Zamenjajte ga</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Programi preprečujejo računalniku, da bi se zaustavil, prisilna zaustavitev pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Da bi program zaprli, klknite Prekini in nato zaprite program.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Programi preprečujejo računalniku, da bi se ponovno zagnal, prisilna zaustavitev pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Programi preprečujejo računalniku, da bi obmiroval, prisilna zaustavitev pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Programi preprečujejo računalniku, da bi zaspal, prisilna zaustavitev pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Programi preprečujejo računalniku, da bi se odjavil, prisilna zaustavitev pa lahko povzroči izgubo podatkov.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Izklop</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Ponovni zagon</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Mirovanje</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Spanje</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Ste prepričani, da želite zaustaviti sistem?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Ste prepričani, da želite ponovni zagon?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Ste preričani, da se želite odjaviti?</translation>
    </message>
</context>
</TS>
